==> haskell-hedgehog-0.6.1-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 0.6.1
id: hedgehog-0.6.1-7JbjpztCRoU3cmt995neCj
key: hedgehog-0.6.1-7JbjpztCRoU3cmt995neCj
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Hedgehog will eat all your bugs.
description:
    Hedgehog is a modern property-based testing system, in the spirit of
    QuickCheck. Hedgehog uses integrated shrinking, so shrinks obey the
    invariants of generated values by construction.
    .
    To get started quickly, see the examples:
    <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example>
category: Testing
abi: 60760b827d62c9f2f199d43ed30f9b5e
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Range
import-dirs: /usr/lib/ghc-8.6.4/site-local/hedgehog-0.6.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/hedgehog-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hedgehog-0.6.1
hs-libraries: HShedgehog-0.6.1-7JbjpztCRoU3cmt995neCj
depends:
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 concurrent-output-1.10.9-AKGfwCMHGBF7aZQwtUugDz
    containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
    lifted-async-0.10.0.3-K6tRMIsafCWF4S9Tl4oBP3
    mmorph-1.1.2-5h7GKVLK9ep1Ipfuek8hyY
    monad-control-1.0.2.3-1X2URhF8HacCf5Ysp3ecBG mtl-2.2.2
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-6zBKJcCUqdeLbP1UFGIV0t stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-hZJVZ2zmXw59mRAYP9RXW time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-F1E9AxVLoHK4gnfKIcTrBt unix-2.7.2.2
    wl-pprint-annotated-0.1.0.1-HxSUl9tJmTu8G5KT4ohNSI
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-0.6.1-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 0.6.1
id: hedgehog-0.6.1-AXnFx27cXHl6lCrHAONt77
key: hedgehog-0.6.1-AXnFx27cXHl6lCrHAONt77
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Hedgehog will eat all your bugs.
description:
    Hedgehog is a modern property-based testing system, in the spirit of
    QuickCheck. Hedgehog uses integrated shrinking, so shrinks obey the
    invariants of generated values by construction.
    .
    To get started quickly, see the examples:
    <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example>
category: Testing
abi: e7475aef11496b3db6e165984cb45f3e
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Range
import-dirs: /usr/lib/ghc-8.6.5/site-local/hedgehog-0.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hedgehog-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hedgehog-0.6.1
hs-libraries: HShedgehog-0.6.1-AXnFx27cXHl6lCrHAONt77
depends:
    ansi-terminal-0.8.2-IytGdmUG1lK1dAjqEeG5cq
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 concurrent-output-1.10.9-AmbCKWWIFZy3HCeejN4dTo
    containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH
    lifted-async-0.10.0.4-Gi9PBipolwnDDd5p56fhXZ
    mmorph-1.1.3-FfwptCv2VaAjI2vq7vsWW
    monad-control-1.0.2.3-FeYEsm8P5694VImLZDBXYS mtl-2.2.2
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-njuTV0kmRGB4xSgU2BFrl stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-hZJVZ2zmXw59mRAYP9RXW time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-HGTy7PtJMWjITFSZBfRdND unix-2.7.2.2
    wl-pprint-annotated-0.1.0.1-IYtzXb6WtAl40ds0SR4SjZ
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
